@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Client for connecting to a Vertica database.
 """
@@ -13,7 +12,7 @@ import vertica_python
 LOGGER = getLogger(__name__)
 
 
-class VerticaClient(object):
+class VerticaClient:
     """
     Client for connecting to Vertica.
     """
